@@ -1,7 +1,9 @@
 """Custom registration forms that expects an email address as a username."""
-import md5
+import hashlib
+import os
 
 from django import forms
+from django.conf import settings
 from django.contrib.auth.forms import AuthenticationForm
 from django.contrib.auth.models import User
 from django.utils.translation import ugettext_lazy as _
@@ -21,7 +23,7 @@ def get_md5_hexdigest(email):
     The length is 30 so that it fits into Django's ``User.username`` field.
 
     """
-    return md5.new(email).hexdigest()[0:30]
+    return hashlib.md5(email).hexdigest()[0:30]
 
 
 def generate_username(email):
@@ -57,6 +59,10 @@ class EmailAuthenticationForm(AuthenticationForm):
         self.fields['username'] = forms.CharField(
             label=_("Email"), max_length=256)
 
+    def clean_username(self):
+        """Prevent case-sensitive erros in email/username."""
+        return self.cleaned_data['username'].lower()
+
 
 class EmailRegistrationForm(forms.Form):
     """
@@ -82,6 +88,7 @@ class EmailRegistrationForm(forms.Form):
     password2 = forms.CharField(
         widget=forms.PasswordInput(attrs=attrs_dict, render_value=False),
          label=_("Password (repeat)"))
+    your_name = forms.CharField(required=False)
 
     def clean_email(self):
         """
@@ -106,6 +113,9 @@ class EmailRegistrationForm(forms.Form):
 
         """
         data = self.cleaned_data
+        if data.get('your_name'):
+            # Bot protection. The name field is not visible for human users.
+            raise forms.ValidationError(_('Please enter a valid name.'))
         if not 'email' in data:
             return data
         if ('password1' in data and 'password2' in data):
@@ -116,3 +126,9 @@ class EmailRegistrationForm(forms.Form):
 
         self.cleaned_data['username'] = generate_username(data['email'])
         return self.cleaned_data
+
+    class Media:
+        css = {
+            'all': (os.path.join(
+                settings.STATIC_URL, 'registration_email/css/auth.css'), )
+        }
